==> reds-0.1.0.tgz: package/testing.js <==

/**
 * Module dependencies.
 */

var should = require('should')
  , redis = require('redis')
  , reds = require('./').createSearch('reds')
  , db = redis.createClient()
  , fs = require('fs');

// TODO: porter stemmer
// TODO: singularize
// TODO: remove stopwords.js
// TODO: contribute back ... cache regexps ... benchmark

// Populate text bodies

var strs = [];
strs.push('Tobi really wants four dollars');
strs.push('For some reason tobi is always wanting four dollars');
strs.push('Tobi wants four dollars');
strs.push('Tobi only wants $4');
strs.push('Loki is really fat');
strs.push('Loki, Jane, and Tobi are ferrets');
strs.push('Manny is a cat');
strs.push('Luna is a cat');
strs.push('Mustachio is a cat');

strs.forEach(function(str, i){ reds.index(str, i); });

// search

reds.query(query = 'tobi wants four dollars', function(err, ids){
  if (err) throw err;
  console.log('Search results for "%s":', query);
  ids.forEach(function(id){
    console.log('  - %s', strs[id]);
  });
  process.exit();
}, 'and');

// var start = new Date;
// var text = fs.readFileSync('Readme.md', 'utf8');
// 
// text = 'Just a tiny simple string nothing interesting really \
// but it is just a regular paragraph... not really a book\
// or a large document of any kind.Just a tiny simple string nothing interesting really \
// but it is just a regular paragraph... not really a book\
// or a large document of any kind.Just a tiny simple string nothing interesting really \
// but it is just a regular paragraph... not really a book\
// or a large document of any kind.Just a tiny simple string nothing interesting really \
// but it is just a regular paragraph... not really a book\
// or a large document of any kind.Just a tiny simple string nothing interesting really \
// but it is just a regular paragraph... not really a book\
// or a large document of any kind.Just a tiny simple string nothing interesting really \
// but it is just a regular paragraph... not really a book\
// or a large document of any kind.Just a tiny simple string nothing interesting really \
// but it is just a regular paragraph... not really a book\
// or a large document of any kind.Just a tiny simple string nothing interesting really \
// but it is just a regular paragraph... not really a book\
// or a large document of any kind.';
// 
// console.log();
// console.log('  %dkb', (text.length / 1024).toFixed(2));
// var ops = 100
//   , n = ops;
// 
// while (n--) reds.add(text, Math.random() * 20 | 0);
// 
// reds.add(text, 1, function(){
//   var duration = new Date - start
//    , persec = (1000 / duration) * ops;
//   console.log('  %dms %d ops/s', duration, persec.toFixed(2));
//   console.log();
//   process.exit();
// });

// while (n--) reds.search('document', function(){});
// 
// reds.search('interesting document', function(err, ids){
//   var duration = new Date - start
//    , persec = (1000 / duration) * ops;
//   console.log('  %dms %d ops/s', duration, persec.toFixed(2));
//   console.log();
//   process.exit();
// }, 'and')

==> reds-0.1.1.tgz: package/testing.js <==

/**
 * Module dependencies.
 */

var should = require('should')
  , redis = require('redis')
  , kue = require('kue')
  , reds = require('./').createSearch('webpages')
  , db = redis.createClient()
  , fs = require('fs');

// TODO: porter stemmer
// TODO: singularize
// TODO: remove stopwords.js
// TODO: contribute back ... cache regexps ... benchmark

// Populate text bodies

var strs = [];
strs.push('Tobi really wants four dollars');
strs.push('For some reason tobi is always wanting four dollars');
strs.push('Tobi wants four dollars');
strs.push('Tobi only wants $4');
strs.push('Loki is really fat');
strs.push('Loki, Jane, and Tobi are ferrets');
strs.push('Manny is a cat');
strs.push('Luna is a cat');
strs.push('Mustachio is a cat');

// strs.forEach(function(str, i){ reds.index(str, i); });
// 
// // search
// 
// reds.query(query = 'tobi wants four dollars', function(err, ids){
//   if (err) throw err;
//   console.log('Search results for "%s":', query);
//   ids.forEach(function(id){
//     console.log('  - %s', strs[id]);
//   });
//   process.exit();
// }, 'and');

var start = new Date;
// var text = fs.readFileSync('Readme.md', 'utf8');
// 
// text = 'Just a tiny simple string nothing interesting really \
// but it is just a regular paragraph... not really a book\
// or a large document of any kind.Just a tiny simple string nothing interesting really \
// but it is just a regular paragraph... not really a book\
// or a large document of any kind.Just a tiny simple string nothing interesting really \
// but it is just a regular paragraph... not really a book\
// or a large document of any kind.Just a tiny simple string nothing interesting really \
// but it is just a regular paragraph... not really a book\
// or a large document of any kind.Just a tiny simple string nothing interesting really \
// but it is just a regular paragraph... not really a book\
// or a large document of any kind.Just a tiny simple string nothing interesting really \
// but it is just a regular paragraph... not really a book\
// or a large document of any kind.Just a tiny simple string nothing interesting really \
// but it is just a regular paragraph... not really a book\
// or a large document of any kind.Just a tiny simple string nothing interesting really \
// but it is just a regular paragraph... not really a book\
// or a large document of any kind.';
// 
// console.log();
// console.log('  %dkb', (text.length / 1024).toFixed(2));
var ops = 100
  , n = ops;
// 
// while (n--) reds.add(text, Math.random() * 20 | 0);
// 
// reds.add(text, 1, function(){
//   var duration = new Date - start
//    , persec = (1000 / duration) * ops;
//   console.log('  %dms %d ops/s', duration, persec.toFixed(2));
//   console.log();
//   process.exit();
// });

while (n--) reds.query('music', function(){});

reds
  .query('music')
  .end(function(err, ids){
    var duration = new Date - start
     , persec = (1000 / duration) * ops;
    console.log(ids);
    console.log('  %dms %d ops/s', duration, persec.toFixed(2));
    console.log();
    process.exit();
  });
